#[repr(i32)]pub enum EnvelopeAlgorithm {
Unspecified = 0,
Aes256Gcm = 1,
Chacha20Poly1305 = 2,
}Expand description
AEAD that seals the payload under the KEM-derived key in an envelope.
Variants
Unspecified = 0
Unset; rejected by the broker.
Aes256Gcm = 1
AES-256-GCM.
Chacha20Poly1305 = 2
ChaCha20-Poly1305.
Implementations
Sourceimpl EnvelopeAlgorithm
impl EnvelopeAlgorithm
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of EnvelopeAlgorithm.
Sourcepub fn from_i32(value: i32) -> Option<EnvelopeAlgorithm>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EnvelopeAlgorithm>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EnvelopeAlgorithm, or None if value is not a valid variant.
Sourceimpl EnvelopeAlgorithm
impl EnvelopeAlgorithm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.