#[repr(i32)]pub enum KeyType {
Show 13 variants
Unspecified = 0,
Ed25519 = 1,
Ed25519Nkey = 2,
Rsa2048 = 3,
EcdsaP256 = 10,
EcdsaP384 = 11,
EcdsaP521 = 12,
MlDsa44 = 4,
MlDsa65 = 5,
MlDsa87 = 6,
MlKem512 = 7,
MlKem768 = 8,
MlKem1024 = 9,
}Expand description
Asymmetric key type for key creation, import, signing, and minting.
Variants
Unspecified = 0
Unset; rejected by the broker.
Ed25519 = 1
Raw Ed25519 signing key.
Ed25519Nkey = 2
Ed25519 wrapped in the NATS NKey envelope (needs a nats_type label).
Rsa2048 = 3
RSA-2048.
EcdsaP256 = 10
ECDSA P-256.
EcdsaP384 = 11
ECDSA P-384.
EcdsaP521 = 12
ECDSA P-521.
MlDsa44 = 4
ML-DSA (FIPS 204) post-quantum signatures, parameter set 44.
MlDsa65 = 5
ML-DSA parameter set 65.
MlDsa87 = 6
ML-DSA parameter set 87.
MlKem512 = 7
ML-KEM (FIPS 203) post-quantum key encapsulation, parameter set 512.
MlKem768 = 8
ML-KEM parameter set 768.
MlKem1024 = 9
ML-KEM parameter set 1024.
Implementations
Sourceimpl KeyType
impl KeyType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.